@@ -1,6 +1,6 @@
 import logging
 
-from nomnomdata.engine.components import Engine, Parameter, ParameterGroup
+from nomnomdata.engine import Engine, Parameter, ParameterGroup
 from nomnomdata.engine.parameters import Int, String
 
 logger = logging.getLogger("engine.hello_world")
